@@ -1,6 +1,7 @@
 import string
 import traceback
-from typing import Union, List
+
+from typing import Union, List, Optional
 import numpy as np
 import json
 from ..handler.nativeMethods import NativeMethods
@@ -11,6 +12,7 @@ from ..helper.result_objects.deleteResult import FaceDeleteResult
 from ..helper.result_objects.enrollPredictResult import FaceEnrollPredictResult
 from ..helper.result_objects.faceValidationResult import FaceValidationResult
 from ..helper.result_objects.isoFaceResult import ISOFaceResult
+from ..helper.result_objects.antispoofCheckResult import AntispoofCheckResult
 from ..helper.utils import FaceValidationCode
 from ..settings.cacheType import CacheType
 from ..settings.configuration import ConfigObject
@@ -203,10 +205,13 @@ class Face(metaclass=Singleton):
         try:
             processed_document=self._doc_scan_face(image_data=doc_data)
             if processed_document.get("doc_face",{}).get("document_data",{}).get("document_validation_status",-1)!=0:
-                 return FaceCompareResult(message= processed_document.get("doc_face",{}).get("document_data",{}).get("status_message","Something went wrong while processing document image"))
+                 if processed_document.get("doc_face",{}).get("document_data",{}).get("status_message","Unable to detect face in the document.").strip()=="":
+                        return FaceCompareResult(message="Unable to detect face in the document.")
+                 return FaceCompareResult(message= processed_document.get("doc_face",{}).get("document_data",{}).get("status_message","Unable to detect face in the document."))
         
             cropped_face_array = processed_document.get("doc_face",{}).get("cropped_face")
-            
+            if cropped_face_array is None:
+                 return FaceCompareResult(message= "Unable to detect face in the document.")
             if cropped_face_array is not None:
             
                 face_compare_json_data_all = self.face_factor_processor.compare_files(
@@ -410,3 +415,27 @@ class Face(metaclass=Singleton):
         except Exception as e:
             print(e, traceback.format_exc())
             return ISOFaceResult(message=self.message.EXCEPTION_ERROR_GET_ISO_FACE)
+   
+    def antispoof_check(self, image_data: np.array, config_object: Optional[ConfigObject] = None) -> AntispoofCheckResult:
+            try:
+                # Call the processor to check for antispoofing
+                json_data = self.face_factor_processor.antispoof_check(image_data, config_object=config_object)
+
+                # Validate response
+                if json_data is None:
+                    return AntispoofCheckResult(status=-100, message="No response from antispoofing processor.", is_antispoof=False)
+
+                # Check if there is an error in processing
+                if json_data.get("call_status", {}).get("return_status",0) != 0:
+                    error_message = json_data.get("call_status", {}).get("return_message", "Error during antispoofing check.")
+                    return AntispoofCheckResult(status=json_data.get("call_status", {}).get("return_status"), message=error_message, is_antispoof=False)
+                
+                if json_data.get("antispoofing", 0) in [-1,-2,-3,-4,-5,-6,-100]:
+                    return AntispoofCheckResult(status=json_data.get("antispoofing", 0), message=self.message.APP_MESSAGES.get(json_data.get("antispoofing", 0), "Error during antispoofing check."), is_antispoof=False)
+                # Check antispoofing result
+                is_spoof_detected = json_data.get("antispoofing", 0) == 1
+                return AntispoofCheckResult(status=0, message="No spoofing detected." if not is_spoof_detected else "Spoofing detected.", is_antispoof=is_spoof_detected)
+
+            except Exception as e:
+                print("Exception occurred:", e, traceback.format_exc())
+                return AntispoofCheckResult(status=-100, message="Exception occurred during antispoofing check.", is_antispoof=False)
\ No newline at end of file
