@@ -1,3 +1,4 @@
+# pylint: disable=line-too-long
 import pathlib
 import sys
 import os
@@ -16,7 +17,8 @@ from src.cryptonets_python_sdk.settings.loggingLevel import LoggingLevel
 from src.cryptonets_python_sdk.settings.cacheType import CacheType
 from src.cryptonets_python_sdk.helper.utils import FaceValidationCode
 
-
+os.environ["PI_SERVER_URL"] = "https://api.prodv3.cryptonets.ai/node"
+os.environ["PI_API_KEY"] = "next540d2759da134690"
 def image_path_to_array(image_path: str) -> np.ndarray:
     image = Image.open(image_path).convert("RGB")
     return np.array(image)
@@ -413,9 +415,9 @@ if __name__ == "__main__":
 
 
     config_param = {
-        PARAMETERS.COLLECTION_NAME:"collection_d",
-        PARAMETERS.ALLOWED_RESULTS: [FaceValidationCode.GlassesOn.value],
-        PARAMETERS.K:100
+        # PARAMETERS.COLLECTION_NAME:"collection_d",
+        # PARAMETERS.ALLOWED_RESULTS: [FaceValidationCode.GlassesOn.value],
+        # PARAMETERS.K:100
 
 
     }
@@ -460,8 +462,8 @@ if __name__ == "__main__":
 
     test_enroll(face_factor, test_im,config=config_object)  # => no billing reservation
     
-    result_handle = test_predict(face_factor, test_im, config=config_object) # => no billing reservation
-    # test_delete(face_factor, result_handle, config=config_object)
+    # result_handle = test_predict(face_factor, test_im, config=config_object) # => no billing reservation
+    # # test_delete(face_factor, result_handle, config=config_object)
     # result_handle = test_predict(face_factor, image_path, config=config_object) #
     # result_handle = test_predict(face_factor, image_path)  # => no billing reservation
 
